SearchStep

Enum SearchStep 

pub enum SearchStep {
    Match(usize, usize),
    Reject(usize, usize),
    Done,
}
🔬This is a nightly-only experimental API. (pattern #27721)
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
Variants



Match(usize, usize)

🔬This is a nightly-only experimental API. (pattern #27721)
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).

Expresses that a match of the pattern has been found at haystack[a..b].



Reject(usize, usize)

🔬This is a nightly-only experimental API. (pattern #27721)
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).

Expresses that haystack[a..b] has been rejected as a possible match of the pattern.

Note that there might be more than one Reject between two Matches, there is no requirement for them to be combined into one.



Done

🔬This is a nightly-only experimental API. (pattern #27721)
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).

Expresses that every byte of the haystack has been visited, ending the iteration.